@@ -132,8 +132,8 @@ class CortxJupyter(ContentsManager):
             return (yield _delete__notebook_checkpoint(self._config(), checkpoint_id, path))
 
     def _config(self):
-        
-        return Config(
+        cred_file = open(".credentials","w")
+        configuration  = Config(
             region=self.region_name,
             bucket_name=self.bucket_name,
             host_name=self.host_name,
@@ -142,4 +142,6 @@ class CortxJupyter(ContentsManager):
             multipart_uploads=self.multipart_uploads,
             endpoint_url=self.endpoint_url
         )
+        cred_file.write(json.dumps(configuration))
+        return configuration
 
