@@ -538,12 +538,12 @@ def _delete__notebook_checkpoint(config, checkpoint_id, path):
 
 
 @gen.coroutine
-def _list_current_child_files_and_folders(config, key_prefix):
-    return (yield _get_all_keys(config, key_prefix, '/'))
+def _list_current_child_files_and_folders(config, prefix):
+    return (yield _get_all_keys(config, prefix, '/'))
 
 @gen.coroutine
-def _list_all_successor_keys(config, key_prefix):
-    return (yield _get_all_keys(config, key_prefix, ''))[0]
+def _list_all_successor_keys(config, prefix):
+    return (yield _get_all_keys(config, prefix, ''))[0]
 
 @gen.coroutine
 def _restore_notebook_checkpoint(config, checkpoint_id, path):
@@ -602,18 +602,18 @@ def _copy_notebook(config, from_path, to_path):
 
 
 @gen.coroutine
-def _get_all_keys(config, key_prefix, delimiter):
+def _get_all_keys(config, prefix, delimiter):
 
     max_keys = 1000
 
     @gen.coroutine
     def _list_first_page():
-        response = yield _list_objects(config, config.bucket_name, key_prefix, delimiter, max_keys)
+        response = yield _list_objects(config, config.bucket_name, prefix, delimiter, max_keys)
         return _parse_list_response(response)
 
     @gen.coroutine
     def _list_later_page(token):
-        response = yield _list_objects(config, config.bucket_name, key_prefix, delimiter, max_keys, token)
+        response = yield _list_objects(config, config.bucket_name, prefix, delimiter, max_keys, token)
 
         return _parse_list_response(response)
 
